# Changelog

This is a manually generated log to track changes to the repository for each release. 
Each section should include general headers such as **Implemented enhancements** 
and **Merged pull requests**. All closed issued and bug fixes should be 
represented by the pull requests that fixed them.
Critical items to know are:

 - renamed commands
 - deprecated / removed commands
 - changed defaults
 - backward incompatible changes
 - migration guidance
 - changed behaviour

versions here coincide with releases on pypi.

## [master](https://github.com/openbases/openbases-python/tree/master)
 - validation shouldn't continue if paper doesn't exist (0.0.54)
 - papers module validation functions (0.0.53)
 - adding color for "spec" (specification) to match schema.org (0.0.52)
 - adding custom color specification (0.0.51)
 - bug with name needing dashes replaced with underscores (0.0.5)
 - fixing bug with ob-badge (0.0.4)
 - adding badges module, and entry point ob-badge (0.0.3)
 - missing requests dependency (0.0.2)
 - adding icons endpoint `ob-icons` (0.0.1)
 - added base functions to get fields from paper markdown and tests (0.0.0)
 - package registration (still under development)
